:star: :guitar: :octocat: :godmode:
# highway_star
scrap biographies of celebrities on wikipedia that committed suicide and plot their life course

# HOW TO RUN LOCALLY 

## Using virtual environment 

### On Linux/MacOS
start by creating a virtual environment with the command line

```python3 -m venv env```

then, activate it with :

```source env/bin/activate```

install requirements

``python3 -m pip install -r requirements.txt``

finally, run main

``python3 main.py``

### On WINDOWS

start by creating a virtual environment with the command line

``py -m venv env``

```python3 -m venv env```

then, activate it with :

```.\env\Scripts\activate```

install requirements

``py -m pip install -r requirements.txt``

finally, run main

``py main.py``